# Copyright (C) 2008 by Juergen Beisert
#
# See CREDITS for details about who has contributed to this project.
#
# For further information about the PTXdist project and license conditions
# see the README file.
#

#
# We provide this package
#
PACKAGES-$(PTXCONF_SWITCHER) += switcher

DO_TRUNK_ONLY := 1
#
# Paths and names
#
ifndef DO_TRUNK_ONLY
SWITCHER_VERSION	:= 0.0.1
SWITCHER		:= switcher-$(SWITCHER_VERSION)
SWITCHER_SUFFIX		:= tar.gz
SWITCHER_URL		:= http://www.kreuzholzen.de/src/switcher/$(SWITCHER).$(SWITCHER_SUFFIX)
SWITCHER_SOURCE		:= $(SRCDIR)/$(SWITCHER).$(SWITCHER_SUFFIX)
SWITCHER_DIR		:= $(BUILDDIR)/$(SWITCHER)
endif

ifdef DO_TRUNK_ONLY
SWITCHER_VERSION	:= trunk
SWITCHER		:= switcher-$(SWITCHER_VERSION)
SWITCHER_SUFFIX		:=
SWITCHER_URL		:= file://local_src/$(SWITCHER)
SWITCHER_SOURCE		:= $(SRCDIR)/$(SWITCHER)
SWITCHER_DIR		:= $(BUILDDIR)/$(SWITCHER)
endif

# ----------------------------------------------------------------------------
# Get
# ----------------------------------------------------------------------------

switcher_get: $(STATEDIR)/switcher.get

$(STATEDIR)/switcher.get: $(switcher_get_deps_default)
	@$(call targetinfo, $@)
	@$(call touch, $@)

$(SWITCHER_SOURCE):
	@$(call targetinfo, $@)
	@$(call get, SWITCHER)

# ----------------------------------------------------------------------------
# Extract
# ----------------------------------------------------------------------------

switcher_extract: $(STATEDIR)/switcher.extract

$(STATEDIR)/switcher.extract: $(switcher_extract_deps_default)
	@$(call targetinfo, $@)
	@$(call clean, $(SWITCHER_DIR))
	@$(call extract, SWITCHER)
	@$(call patchin, SWITCHER)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Prepare
# ----------------------------------------------------------------------------

switcher_prepare: $(STATEDIR)/switcher.prepare

SWITCHER_PATH	:= PATH=$(CROSS_PATH)
SWITCHER_ENV 	:= $(CROSS_ENV)

#
# autoconf
#
SWITCHER_AUTOCONF := $(CROSS_AUTOCONF_USR) \
		--disable-dependency-tracking

SWITCHER_AUTOCONF += --with-gid=$(PTXCONF_SWITCHER_GID)

ifdef PTXCONF_SWITCHER_DEBUG
SWITCHER_AUTOCONF += --enable-debug=yes
else
SWITCHER_AUTOCONF += --enable-debug=no
endif

ifdef PTXCONF_SWITCHER_IOWARRIOR
SWITCHER_AUTOCONF += --enable-iowarrior=yes
else
SWITCHER_AUTOCONF += --enable-iowarrior=no
endif

ifdef PTXCONF_SWITCHER_ATMEL1
SWITCHER_AUTOCONF += --enable-atmel1=yes
else 
SWITCHER_AUTOCONF += --enable-atmel1=no
endif

$(STATEDIR)/switcher.prepare: $(switcher_prepare_deps_default)
	@$(call targetinfo, $@)
	cd $(SWITCHER_DIR) && \
		$(SWITCHER_PATH) $(SWITCHER_ENV) \
		./configure $(SWITCHER_AUTOCONF)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Compile
# ----------------------------------------------------------------------------

switcher_compile: $(STATEDIR)/switcher.compile

$(STATEDIR)/switcher.compile: $(switcher_compile_deps_default)
	@$(call targetinfo, $@)
	@cd $(SWITCHER_DIR) && $(CROSS_ENV) $(SWITCHER_PATH) \
		$(MAKE) $(PARALLELMFLAGS)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Install
# ----------------------------------------------------------------------------

switcher_install: $(STATEDIR)/switcher.install

$(STATEDIR)/switcher.install: $(switcher_install_deps_default)
	@$(call targetinfo, $@)
	@$(call install, SWITCHER)
	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Target-Install
# ----------------------------------------------------------------------------

switcher_targetinstall: $(STATEDIR)/switcher.targetinstall

$(STATEDIR)/switcher.targetinstall: $(switcher_targetinstall_deps_default)
	@$(call targetinfo, $@)

	@$(call install_init, switcher)
	@$(call install_fixup, switcher,PACKAGE,switcher)
	@$(call install_fixup, switcher,PRIORITY,optional)
	@$(call install_fixup, switcher,VERSION,$(SWITCHER_VERSION))
	@$(call install_fixup, switcher,SECTION,base)
	@$(call install_fixup, switcher,AUTHOR,"Juergen Beisert <juergen\@kreuzholzen.de>")
	@$(call install_fixup, switcher,DEPENDS,)
	@$(call install_fixup, switcher,DESCRIPTION,missing)

# SGID must be set: 2xxx
	@$(call install_copy, switcher, 0, $(PTXCONF_SWITCHER_GID), 2755, \
		$(SWITCHER_DIR)/src/switcher, /bin/switcher)

ifdef PTXCONF_SWITCHER_CONFIG
# read access only for the group, no permission for all
	@$(call install_copy, switcher, 0, $(PTXCONF_SWITCHER_GID), 0640, \
		$(PTXDIST_WORKSPACE)/projectroot/etc/switcher.conf, \
		/etc/switcher.conf, n)
endif
#
# to support the full security feature, a udev rule should also be added to
# create all relevant device nodes with $(PTXCONF_SWITCHER_GID) and read/write
# access only for root and this group! Read the comments in switcher.in
# carefully.
#
	@$(call install_finish, switcher)

	@$(call touch, $@)

# ----------------------------------------------------------------------------
# Clean
# ----------------------------------------------------------------------------

switcher_clean:
ifdef DO_TRUNK_ONLY
	cd $(SWITCHER_DIR) && $(CROSS_ENV) $(SWITCHER_PATH) \
		$(MAKE) $(PARALLELMFLAGS) clean
endif
	@rm -rf $(STATEDIR)/switcher.*
	@rm -rf $(IMAGEDIR)/switcher_*
	@rm -rf $(SWITCHER_DIR)

# vim: syntax=make
